==> hubzero-cms-1.3.0_1.3.0.30.orig.tar.gz: hubzero-cms-1.3.0-1.3.0.30/cms/components/com_tools/views/admin/tmpl/display.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2011 Purdue University. All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');
?>
<div id="output">
<?php if ($this->getError()) { ?>
	<p class="error">
		<strong><?php echo JText::_('COM_TOOLS_NOTICE_PROBLEMS'); ?></strong><br />
		<?php echo implode('<br />* ', $this->getErrors()); ?>
	</p>
<?php } ?>
<?php if ($this->messages && !empty($this->messages)) { ?>
	<p class="passed">
		<strong><?php echo JText::_('COM_TOOLS_NOTICE_OK_ACTIONS'); ?></strong><br />
		<?php echo implode('<br />* ', $this->messages); ?>
	</p>
<?php } ?>
</div>

==> hubzero-cms_20130801.1.orig.tar.gz: hubzero-cms-20130801.1/cms/components/com_tools/views/admin/tmpl/display.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2011 Purdue University. All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');
?>
<div id="output">
<?php if ($this->getError()) { ?>
	<p class="error">
		<strong><?php echo JText::_('NOTICE_PROBLEMS'); ?></strong><br />
		<?php echo implode('<br />* ', $this->getErrors()); ?>
	</p>
<?php } ?>
<?php if ($this->messages && !empty($this->messages)) { ?>
	<p class="passed">
		<strong><?php echo JText::_('NOTICE_OK_ACTIONS'); ?></strong><br />
		<?php echo implode('<br />* ', $this->messages); ?>
	</p>
<?php } ?>
</div>
